@@ -143,6 +143,11 @@ class FleetManagementServiceTransport(abc.ABC):
                 default_timeout=None,
                 client_info=client_info,
             ),
+            self.list_vessels_with_status: gapic_v1.method.wrap_method(
+                self.list_vessels_with_status,
+                default_timeout=None,
+                client_info=client_info,
+            ),
             self.add_vessel: gapic_v1.method.wrap_method(
                 self.add_vessel,
                 default_timeout=None,
@@ -253,6 +258,15 @@ class FleetManagementServiceTransport(abc.ABC):
             ]]:
         raise NotImplementedError()
 
+    @property
+    def list_vessels_with_status(self) -> typing.Callable[
+            [service.ListVesselsWithStatusRequest],
+            typing.Union[
+                service.Vessels,
+                typing.Awaitable[service.Vessels]
+            ]]:
+        raise NotImplementedError()
+
     @property
     def add_vessel(self) -> typing.Callable[
             [service.AddVesselRequest],
