@@ -4,6 +4,7 @@ from oceanbolt.sdk.data import TradeFlows, TradeFlowTimeseries
 from oceanbolt.sdk.data import PortCalls, PortCallTimeseries, PortParticulars
 from oceanbolt.sdk.data import TonnageZoneTimeseries, FleetSpeedTimeseries, ChineseWatersTimeseries, FleetStatusTimeseries, FleetGrowthTimeseries, ZoneChangesTimeseries, CustomPolygonTimeseries
 from oceanbolt.sdk.data import CongestionVessels, CongestionTimeseries
+from oceanbolt.sdk.data import DryDockTimeseries, DryDockCurrentVessels, DryDockHistoricalStays
 
 __client__ = APIClient()
 
@@ -61,6 +62,21 @@ def test_congestion_timeseries():
     assert len(df) > 0
 
 
+def test_drydock_historical_stays():
+    df = DryDockHistoricalStays(__client__).get(port_id=[403], start_date="2021-01-01")
+    assert len(df) > 0
+
+
+def test_drydock_live_vessels():
+    df = DryDockCurrentVessels(__client__).get(country_code=["cn"], start_date="2021-01-01")
+    assert len(df) > 0
+
+
+def test_drydock_timeseries():
+    df = DryDockTimeseries(__client__).get(country_code=["cn"], start_date="2021-01-01")
+    assert len(df) > 0
+
+
 def test_port_calls():
     df = PortCalls(__client__).get(country_code=["cn"], start_date="2021-01-01")
     assert len(df) > 0
@@ -81,6 +97,11 @@ def test_tonnage_count():
     assert len(df) > 0
 
 
+def test_tonnage_count_empty():
+    df = TonnageZoneTimeseries(__client__).get(sub_segment=["babycape"], zone_id=[22], port_status=["in_port"], laden_status=["laden"], start_date="2021-07-25", end_date="2021-07-26")
+    assert len(df) == 0
+
+
 def test_fleet_speed():
     df = FleetSpeedTimeseries(__client__).get(segment=["handysize"], start_date="2021-01-01")
     assert len(df) > 0
